import Vue from 'vue';
import Router from 'vue-router';
import { AuthGuard } from '@/utils';
import qs from 'qs';
import { globalRoutes, indexRoutes} from '@/router'
import { AppService } from '@/studio-core/service/app-service/AppService';

Vue.use(Router);

const appService = new AppService();

const router = new Router({
    routes: [
        {
            path: '/website/:website?',
            beforeEnter: (to: any, from: any, next: any) => {
                const routerParamsName = 'website';
                const params: any = {};
                if (to.params && to.params[routerParamsName]) {
                    Object.assign(params, qs.parse(to.params[routerParamsName], { delimiter: ';' }));
                }
                const url: string = '/appdata';
                const auth: Promise<any> = AuthGuard.getInstance().authGuard(url, params, router);
                auth.then(() => {
                    next();
                }).catch(() => {
                    next();
                });
                appService.navHistory.indexMeta = {
                    caption: 'app.views.website.title',
                    info:'',
                    viewType: 'APPINDEX',
                    parameters: [
                        { pathName: 'website', parameterName: 'website' },
                    ],
                    requireAuth: true,
                };
            },
            meta: {  
                caption: 'app.views.website.title',
                info:'',
                viewType: 'APPINDEX',
                parameters: [
                    { pathName: 'website', parameterName: 'website' },
                ],
                requireAuth: true,
            },
            component: () => import('@pages/ungroup/web-site/web-site.vue'),
            children: [
                {
                    path: 'websites/:website?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.website.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'website', parameterName: 'website' },
                            { pathName: 'websites', parameterName: 'website' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/web-site/web-site-grid-view/web-site-grid-view.vue'),
                },
                {
                    path: 'websites/:website?/websitechannels/:websitechannel?/editview/:editview?',
                    meta: {
                        caption: 'entities.websitechannel.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'website', parameterName: 'website' },
                            { pathName: 'websites', parameterName: 'website' },
                            { pathName: 'websitechannels', parameterName: 'websitechannel' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/web-site/web-site-channel-edit-view/web-site-channel-edit-view.vue'),
                },
                {
                    path: 'websitechannels/:websitechannel?/editview/:editview?',
                    meta: {
                        caption: 'entities.websitechannel.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'website', parameterName: 'website' },
                            { pathName: 'websitechannels', parameterName: 'websitechannel' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/web-site/web-site-channel-edit-view/web-site-channel-edit-view.vue'),
                },
                {
                    path: 'websites/:website?/websitechannels/:websitechannel?/websitecontents/:websitecontent?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.websitecontent.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'website', parameterName: 'website' },
                            { pathName: 'websites', parameterName: 'website' },
                            { pathName: 'websitechannels', parameterName: 'websitechannel' },
                            { pathName: 'websitecontents', parameterName: 'websitecontent' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/web-site/web-site-content-grid-view/web-site-content-grid-view.vue'),
                },
                {
                    path: 'websites/:website?/websitecontents/:websitecontent?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.websitecontent.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'website', parameterName: 'website' },
                            { pathName: 'websites', parameterName: 'website' },
                            { pathName: 'websitecontents', parameterName: 'websitecontent' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/web-site/web-site-content-grid-view/web-site-content-grid-view.vue'),
                },
                {
                    path: 'websitechannels/:websitechannel?/websitecontents/:websitecontent?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.websitecontent.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'website', parameterName: 'website' },
                            { pathName: 'websitechannels', parameterName: 'websitechannel' },
                            { pathName: 'websitecontents', parameterName: 'websitecontent' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/web-site/web-site-content-grid-view/web-site-content-grid-view.vue'),
                },
                {
                    path: 'websitecontents/:websitecontent?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.websitecontent.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'website', parameterName: 'website' },
                            { pathName: 'websitecontents', parameterName: 'websitecontent' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/web-site/web-site-content-grid-view/web-site-content-grid-view.vue'),
                },
                {
                    path: 'websites/:website?/websitechannels/:websitechannel?/contenttreeview/:contenttreeview?',
                    meta: {
                        caption: 'entities.websitechannel.views.contenttreeview.title',
                        info:'',
                        parameters: [
                            { pathName: 'website', parameterName: 'website' },
                            { pathName: 'websites', parameterName: 'website' },
                            { pathName: 'websitechannels', parameterName: 'websitechannel' },
                            { pathName: 'contenttreeview', parameterName: 'contenttreeview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/web-site/web-site-channel-content-tree-view/web-site-channel-content-tree-view.vue'),
                },
                {
                    path: 'websitechannels/:websitechannel?/contenttreeview/:contenttreeview?',
                    meta: {
                        caption: 'entities.websitechannel.views.contenttreeview.title',
                        info:'',
                        parameters: [
                            { pathName: 'website', parameterName: 'website' },
                            { pathName: 'websitechannels', parameterName: 'websitechannel' },
                            { pathName: 'contenttreeview', parameterName: 'contenttreeview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/web-site/web-site-channel-content-tree-view/web-site-channel-content-tree-view.vue'),
                },
                {
                    path: 'websites/:website?/editview/:editview?',
                    meta: {
                        caption: 'entities.website.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'website', parameterName: 'website' },
                            { pathName: 'websites', parameterName: 'website' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/web-site/web-site-edit-view/web-site-edit-view.vue'),
                },
                {
                    path: 'websites/:website?/websitechannels/:websitechannel?/websitecontents/:websitecontent?/editview/:editview?',
                    meta: {
                        caption: 'entities.websitecontent.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'website', parameterName: 'website' },
                            { pathName: 'websites', parameterName: 'website' },
                            { pathName: 'websitechannels', parameterName: 'websitechannel' },
                            { pathName: 'websitecontents', parameterName: 'websitecontent' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/web-site/web-site-content-edit-view/web-site-content-edit-view.vue'),
                },
                {
                    path: 'websites/:website?/websitecontents/:websitecontent?/editview/:editview?',
                    meta: {
                        caption: 'entities.websitecontent.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'website', parameterName: 'website' },
                            { pathName: 'websites', parameterName: 'website' },
                            { pathName: 'websitecontents', parameterName: 'websitecontent' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/web-site/web-site-content-edit-view/web-site-content-edit-view.vue'),
                },
                {
                    path: 'websitechannels/:websitechannel?/websitecontents/:websitecontent?/editview/:editview?',
                    meta: {
                        caption: 'entities.websitecontent.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'website', parameterName: 'website' },
                            { pathName: 'websitechannels', parameterName: 'websitechannel' },
                            { pathName: 'websitecontents', parameterName: 'websitecontent' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/web-site/web-site-content-edit-view/web-site-content-edit-view.vue'),
                },
                {
                    path: 'websitecontents/:websitecontent?/editview/:editview?',
                    meta: {
                        caption: 'entities.websitecontent.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'website', parameterName: 'website' },
                            { pathName: 'websitecontents', parameterName: 'websitecontent' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/web-site/web-site-content-edit-view/web-site-content-edit-view.vue'),
                },
                {
                    path: 'websites/:website?/websiteresources/:websiteresource?/editview/:editview?',
                    meta: {
                        caption: 'entities.websiteresource.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'website', parameterName: 'website' },
                            { pathName: 'websites', parameterName: 'website' },
                            { pathName: 'websiteresources', parameterName: 'websiteresource' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/web-site/web-site-resource-edit-view/web-site-resource-edit-view.vue'),
                },
                {
                    path: 'websiteresources/:websiteresource?/editview/:editview?',
                    meta: {
                        caption: 'entities.websiteresource.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'website', parameterName: 'website' },
                            { pathName: 'websiteresources', parameterName: 'websiteresource' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/web-site/web-site-resource-edit-view/web-site-resource-edit-view.vue'),
                },
                {
                    path: 'websites/:website?/websitechannels/:websitechannel?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.websitechannel.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'website', parameterName: 'website' },
                            { pathName: 'websites', parameterName: 'website' },
                            { pathName: 'websitechannels', parameterName: 'websitechannel' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/web-site/web-site-channel-grid-view/web-site-channel-grid-view.vue'),
                },
                {
                    path: 'websitechannels/:websitechannel?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.websitechannel.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'website', parameterName: 'website' },
                            { pathName: 'websitechannels', parameterName: 'websitechannel' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/web-site/web-site-channel-grid-view/web-site-channel-grid-view.vue'),
                },
                {
                    path: 'websites/:website?/websiteresources/:websiteresource?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.websiteresource.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'website', parameterName: 'website' },
                            { pathName: 'websites', parameterName: 'website' },
                            { pathName: 'websiteresources', parameterName: 'websiteresource' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/web-site/web-site-resource-grid-view/web-site-resource-grid-view.vue'),
                },
                {
                    path: 'websiteresources/:websiteresource?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.websiteresource.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'website', parameterName: 'website' },
                            { pathName: 'websiteresources', parameterName: 'websiteresource' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/web-site/web-site-resource-grid-view/web-site-resource-grid-view.vue'),
                },
            ...indexRoutes,
            ],
        },
        ...globalRoutes,
        {
            path: '/login/:login?',
            name: 'login',
            meta: {  
                caption: '登录',
                viewType: 'login',
                requireAuth: false,
                ignoreAddPage: true,
            },
            beforeEnter: (to: any, from: any, next: any) => {
                appService.navHistory.reset();
                next();
            },
            component: () => import('@components/login/login.vue'),
        },
        {
            path: '/404',
            component: () => import('@components/404/404.vue')
        },
        {
            path: '/500',
            component: () => import('@components/500/500.vue')
        },
        {
            path: '*',
            redirect: 'website'
        }
    ]
});

router.beforeEach((to: any, from: any, next: any) => {
    if (to.meta && !to.meta.ignoreAddPage) {
        appService.navHistory.add(to);
    }
    next();
});

export default router;