import { Subject } from 'rxjs';
import { TreeExpViewBase } from '@/studio-core';
import WebSiteChannelService from '@/service/web-site-channel/web-site-channel-service';
import TreeExpViewEngine from '@engine/view/tree-exp-view-engine';

/**
 * 频道内容视图基类
 *
 * @export
 * @class WebSiteChannelContentTreeViewBase
 * @extends {TreeExpViewBase}
 */
export class WebSiteChannelContentTreeViewBase extends TreeExpViewBase {

    /**
     * 实体服务对象
     *
     * @type {WebSiteChannelService}
     * @memberof WebSiteChannelContentTreeViewBase
     */
    protected appEntityService: WebSiteChannelService = new WebSiteChannelService;


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof WebSiteChannelContentTreeViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof WebSiteChannelContentTreeViewBase
     */
    protected model: any = {
        srfCaption: 'entities.websitechannel.views.contenttreeview.caption',
        srfTitle: 'entities.websitechannel.views.contenttreeview.title',
        srfSubTitle: 'entities.websitechannel.views.contenttreeview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof WebSiteChannelContentTreeViewBase
     */
    protected containerModel: any = {
        view_treeexpbar: { name: 'treeexpbar', type: 'TREEEXPBAR' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = '9b9de8c2724ef66a73380159197e7d72';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof WebSiteChannelContentTreeViewBase
     */
    public engine: TreeExpViewEngine = new TreeExpViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof WebSiteChannelContentTreeViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            treeexpbar: this.$refs.treeexpbar,
            keyPSDEField: 'websitechannel',
            majorPSDEField: 'websitechannelname',
            isLoadDefault: true,
        });
    }

    /**
     * treeexpbar 部件 selectionchange 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof WebSiteChannelContentTreeViewBase
     */
    public treeexpbar_selectionchange($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('treeexpbar', 'selectionchange', $event);
    }

    /**
     * treeexpbar 部件 activated 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof WebSiteChannelContentTreeViewBase
     */
    public treeexpbar_activated($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('treeexpbar', 'activated', $event);
    }

    /**
     * treeexpbar 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof WebSiteChannelContentTreeViewBase
     */
    public treeexpbar_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('treeexpbar', 'load', $event);
    }

    /**
     * 打开新建数据视图
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [fullargs]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof WebSiteChannelContentTreeView
     */
    public newdata(args: any[],fullargs?:any[], params?: any, $event?: any, xData?: any) {
        let localContext:any = null;
        let localViewParam:any =null;
    this.$Notice.warning({ title: '错误', desc: '未指定关系视图' });
    }


    /**
     * 打开编辑数据视图
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [fullargs]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof WebSiteChannelContentTreeView
     */
    public opendata(args: any[],fullargs?:any[],params?: any, $event?: any, xData?: any) {
        let localContext:any = null;
        let localViewParam:any =null;
    this.$Notice.warning({ title: '错误', desc: '未指定关系视图' });
    }



    /**
     * 视图唯一标识
     *
     * @type {string}
     * @memberof WebSiteChannelContentTreeView
     */
    public viewUID: string = 'web-site-web-site-channel-content-tree-view';


}