import { Http,Util } from '@/utils';
import EntityService from '../entity-service';



/**
 * 站点资源服务对象基类
 *
 * @export
 * @class WebSiteResourceServiceBase
 * @extends {EntityServie}
 */
export default class WebSiteResourceServiceBase extends EntityService {

    /**
     * Creates an instance of  WebSiteResourceServiceBase.
     * 
     * @param {*} [opts={}]
     * @memberof  WebSiteResourceServiceBase
     */
    constructor(opts: any = {}) {
        super(opts);
    }

    /**
     * 初始化基础数据
     *
     * @memberof WebSiteResourceServiceBase
     */
    public initBasicData(){
        this.APPLYDEKEY ='websiteresource';
        this.APPDEKEY = 'websiteresourceid';
        this.APPDENAME = 'websiteresources';
        this.APPDETEXT = 'websiteresourcename';
        this.APPNAME = 'website';
        this.SYSTEMNAME = 'ibizbusinesscentral';
    }

// 实体接口

    /**
     * Select接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof WebSiteResourceServiceBase
     */
    public async Select(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.website && context.websiteresource){
            return Http.getInstance().get(`/websites/${context.website}/websiteresources/${context.websiteresource}/select`,isloading);
        }
            return Http.getInstance().get(`/websiteresources/${context.websiteresource}/select`,isloading);
    }

    /**
     * Create接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof WebSiteResourceServiceBase
     */
    public async Create(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.website && true){
            let masterData:any = {};
            Object.assign(data,masterData);
            if(!data.srffrontuf || data.srffrontuf !== "1"){
                data[this.APPDEKEY] = null;
            }
            if(data.srffrontuf){
                delete data.srffrontuf;
            }
            let tempContext:any = JSON.parse(JSON.stringify(context));
            let res:any = await Http.getInstance().post(`/websites/${context.website}/websiteresources`,data,isloading);
            return res;
        }
        let masterData:any = {};
        Object.assign(data,masterData);
        if(!data.srffrontuf || data.srffrontuf !== "1"){
            data[this.APPDEKEY] = null;
        }
        if(data.srffrontuf){
            delete data.srffrontuf;
        }
        let tempContext:any = JSON.parse(JSON.stringify(context));
        let res:any = await Http.getInstance().post(`/websiteresources`,data,isloading);
        return res;
    }

    /**
     * Update接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof WebSiteResourceServiceBase
     */
    public async Update(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.website && context.websiteresource){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().put(`/websites/${context.website}/websiteresources/${context.websiteresource}`,data,isloading);
            return res;
        }
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().put(`/websiteresources/${context.websiteresource}`,data,isloading);
            return res;
    }

    /**
     * Remove接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof WebSiteResourceServiceBase
     */
    public async Remove(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.website && context.websiteresource){
            return Http.getInstance().delete(`/websites/${context.website}/websiteresources/${context.websiteresource}`,isloading);
        }
            return Http.getInstance().delete(`/websiteresources/${context.websiteresource}`,isloading);
    }

    /**
     * Get接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof WebSiteResourceServiceBase
     */
    public async Get(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.website && context.websiteresource){
            let res:any = await Http.getInstance().get(`/websites/${context.website}/websiteresources/${context.websiteresource}`,isloading);
            return res;
        }
            let res:any = await Http.getInstance().get(`/websiteresources/${context.websiteresource}`,isloading);
            return res;
    }

    /**
     * GetDraft接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof WebSiteResourceServiceBase
     */
    public async GetDraft(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.website && true){
            let res:any = await Http.getInstance().get(`/websites/${context.website}/websiteresources/getdraft`,isloading);
            res.data.websiteresource = data.websiteresource;
            return res;
        }
        let res:any = await  Http.getInstance().get(`/websiteresources/getdraft`,isloading);
        res.data.websiteresource = data.websiteresource;
        return res;
    }

    /**
     * CheckKey接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof WebSiteResourceServiceBase
     */
    public async CheckKey(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.website && context.websiteresource){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().post(`/websites/${context.website}/websiteresources/${context.websiteresource}/checkkey`,data,isloading);
            return res;
        }
            return Http.getInstance().post(`/websiteresources/${context.websiteresource}/checkkey`,data,isloading);
    }

    /**
     * Save接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof WebSiteResourceServiceBase
     */
    public async Save(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.website && context.websiteresource){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().post(`/websites/${context.website}/websiteresources/${context.websiteresource}/save`,data,isloading);
            return res;
        }
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().post(`/websiteresources/${context.websiteresource}/save`,data,isloading);
            return res;
    }

    /**
     * FetchDefault接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof WebSiteResourceServiceBase
     */
    public async FetchDefault(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.website && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            return Http.getInstance().get(`/websites/${context.website}/websiteresources/fetchdefault`,tempData,isloading);
        }
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/websiteresources/fetchdefault`,tempData,isloading);
    }
}